package default

import scala.concurrent.duration._

import io.gatling.core.Predef._
import io.gatling.http.Predef._
import io.gatling.jdbc.Predef._

// This class defines several scenarios simulating MultiMonitoring clients.
// A client sends a request once per second.

class MaxClients extends Simulation
{
	val httpProtocol = http
		.baseURL("http://localhost:9018")
		.inferHtmlResources(BlackList(""".*\.css""", """.*\.js""", """.*\.ico"""), WhiteList())	
		
	// Scenario 1: No sorting, no filter.
	object R1
	{
		val r1 = 
		during(5 minute)
		{
			pace(1 second)
			.exec(http("request_1")
			.get("/odata/Jobs?$expand=Destinations,JobMonitor&$count=true&$skip=0&$top=20"))
		}
	}
	
	// Scenario 2: Sort jobs in decreasing MeanFrameRate order.
	object R2
	{
		val r2 = 
		during(5 minute)
		{
			pace(1 second)
			.exec(http("request_2")
			.get("/odata/Jobs?$expand=Destinations,JobMonitor&$count=true&$skip=0&$top=20&$orderby=MeanFrameRate desc, Id desc"))
		}
	}
	
	// Scenario 3: Take the jobs with failed ShortStatus.
	object R3
	{
		val r3 = 
		during(5 minute)
		{
			pace(1 second)
			.exec(http("request_3")
			.get("/odata/Jobs?$expand=Destinations,JobMonitor&$count=true&$skip=0&$top=20&$orderby=Id desc&$filter=ShortStatus eq 'Failed'"))
		}
	}
	
	// Scenario 4: Sort jobs in decreasing ReceptionTime order and take the jobs 
	// with SourceFileName containing the "mp4" string.
	object R4
	{
		val r4 = 
		during(5 minute)
		{
			pace(1 second)
			.exec(http("request_4")
			.get("/odata/Jobs?$expand=Destinations,JobMonitor&$count=true&$skip=0&$top=20&$orderby=ReceptionTime desc, Id desc&$filter=contains(SourceFileName, 'mp4')"))
		}
	}
	
	// Scenario 5: Take jobs whose at least one destination FileName contains "file1".
	object R5
	{
		val r5 = 
		during(5 minute)
		{
			pace(1 second)
			.exec(http("request_5")
			.get("/odata/Jobs?$expand=Destinations,JobMonitor&$count=true&$skip=0&$top=20&$orderby=Id desc&$filter=Destinations/any(o: contains(o/FileName, 'file1'))"))
		}
	}
	
	// Scenario 6: Sort jobs in decreasing MeanByteRate order, then in increasing StartTime order.
	object R6
	{
		val r6 = 
		during(5 minute)
		{
			pace(1 second)
			.exec(http("request_6")
			.get("/odata/Jobs?$expand=Destinations,JobMonitor&$count=true&$skip=0&$top=20&$orderby=MeanByteRate desc, StartTime asc, Id desc"))
		}
	}
	
	// Scenario 7: Sort jobs in increasing ShortStatus order, then in increasing 
	// EndTime order and take only jobs whose \texttt{MeanByteRate} is greater than 30.
	object R7
	{
		val r7 = 
		during(5 minute)
		{
			pace(1 second)
			.exec(http("request_7")
			.get("/odata/Jobs?$expand=Destinations,JobMonitor&$count=true&$skip=0&$top=20&$orderby=ShortStatus asc, EndTime asc, Id desc&$filter=MeanByteRate gt 30"))
		}
	}	
	
	val clients1 = scenario("Clients1").exec(R1.r1)
	val clients2 = scenario("Clients2").exec(R2.r2)
	val clients3 = scenario("Clients3").exec(R3.r3)
	val clients4 = scenario("Clients4").exec(R4.r4)
	val clients5 = scenario("Clients5").exec(R5.r5)
	val clients6 = scenario("Clients6").exec(R6.r6)
	val clients7 = scenario("Clients7").exec(R7.r7)
	
	
	setUp(
	    // Starts uniformly 100 clients during the first second.
		 clients1.inject(rampUsers(100) over (1 seconds))
		// clients2.inject(rampUsers(100) over (1 seconds))
		// clients3.inject(rampUsers(100) over (1 seconds))
		// clients4.inject(rampUsers(100) over (1 seconds))
		// clients5.inject(rampUsers(100) over (1 seconds))
		// clients6.inject(rampUsers(100) over (1 seconds))
		// clients7.inject(rampUsers(100) over (1 seconds))
	).protocols(httpProtocol)
}






nt=true&$skip=0&$top=20&$orderby=ReceptionTime desc, Id desc&$filter=contains(SourceFileName, 'mp4')"))
		}
	}
	
	// Scenario 5: Take jobs whose at least one destination FileName contains "file1".
	object R5
	{
		val r5 = 
		during(5 minute)
		{
			pace(1 second)
			.exec(http("request_5")
			.get("/odata/Jobs?$expand=Destinations,JobMonitor&$count=true&$skip=0&$top=20&$orderby=Id desc&$filter=Destinations/any(o: contains(o/FileName, 'file1'))"))
		}
	}
	
	// Scenario 6: Sort jobs in decreasin